@@ -6,7 +6,8 @@ use OpenCA::OpenSSL;
 use OpenCA::X509;
 use OpenCA::CRL;
 
-my $openssl = new OpenCA::OpenSSL( SHELL=>"/usr/bin/openssl" );
+my $openssl = new OpenCA::OpenSSL (SHELL   => "/usr/bin/openssl",
+                                   GETTEXT => \&gettext);
 my @tmpfiles = ("cert.pem","priv.key","req.pem");
 
 print "Initializing crypto shell ... \n";
@@ -28,8 +29,10 @@ $p = $openssl->genCert( KEYFILE=>"priv.key", REQFILE=>"req.pem", DAYS=>150,
 			OUTFILE=>"cert.pem");
 
 print "Creating a new X509 object ... \n";
-my $X509 = new OpenCA::X509( INFILE=>"cert.pem",
-			     FORMAT=>"PEM", SHELL=>$openssl);
+my $X509 = new OpenCA::X509( INFILE  => "cert.pem",
+                             GETTEXT => \&gettext,
+			     FORMAT  => "PEM",
+                             SHELL=>$openssl);
 
 ## print "Creating a new CRL Object ... \n";
 ## my $CC = new OpenCA::CRL( SHELL=>$openssl, DATA=>$crl );
@@ -42,8 +45,11 @@ my $X509 = new OpenCA::X509( INFILE=>"cert.pem",
 ## print "   * S-Algorithm: " . $CC->getParsed()->{ALGORITHM} . "\n";
 
 print "Creating a new CRL Object (2) ... \n";
-my $CC = new OpenCA::CRL( SHELL=>$openssl, CACERT=>"cert.pem",
-			  CAKEY=>"priv.key", DAYS=>"31" );
+my $CC = new OpenCA::CRL (SHELL   => $openssl,
+                          GETTEXT => \&gettext,
+                          CACERT  => "cert.pem",
+			  CAKEY   => "priv.key",
+                          DAYS    => "31" );
 if( not $CC ) {
 	print "Error!\n";
 	exit;
@@ -66,8 +72,11 @@ print "Sleeping 2 secs ... \n";
 sleep 2;
 
 print "Creating a new CRL Object (3) ... \n";
-my $RR = new OpenCA::CRL( SHELL=>$openssl, CACERT=>"cert.pem",
-			  CAKEY=>"priv.key", DAYS=>"31" );
+my $RR = new OpenCA::CRL (SHELL   => $openssl,
+                          GETTEXT => \&gettext,
+                          CACERT  => "cert.pem",
+			  CAKEY   => "priv.key",
+                          DAYS    => "31");
 if( not $RR ) {
 	print "Error! $? -> $!\n";
 }
@@ -92,5 +101,10 @@ foreach $tmp (@tmpfiles) {
 	unlink( "$tmp" );
 }
 
+sub gettext
+{
+    return $_[0];
+}
+
 exit 0; 
 
